@@ -15,6 +15,11 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+import alpaca_trade_api as tradeapi
+import itertools
+import numpy as np
+import pandas as pd
+import yfinance
 from .cache import DataSourceCacheKey
 from .common import (
     DataCol,
@@ -22,16 +27,12 @@ from .common import (
     to_datetime,
     to_seconds,
     verify_data_source_columns,
+    verify_date_range,
 )
 from .scope import StaticScope
 from abc import ABC, abstractmethod
 from datetime import datetime
 from typing import Final, Iterable, Optional, Union
-import alpaca_trade_api as tradeapi
-import itertools
-import numpy as np
-import pandas as pd
-import yfinance
 
 
 class DataSourceCacheMixin:
@@ -194,6 +195,7 @@ class DataSource(ABC, DataSourceCacheMixin):
         """
         start_date = to_datetime(start_date)
         end_date = to_datetime(end_date)
+        verify_date_range(start_date, end_date)
         if type(symbols) == str and not symbols:
             raise ValueError("Symbols cannot be empty.")
         unique_syms = (
