@@ -145,8 +145,7 @@ class PortfolioBar(NamedTuple):
         equity: Amount of equity in :class:`.Portfolio`.
         margin: Amount of margin in :class:`.Portfolio`.
         market_value: Market value of :class:`.Portfolio`.
-        pnl: Realized profit and loss (PnL) of :class:`.Portfolio`.
-        unrealized_pnl: Unrealized profit and loss (PnL) of
+        pnl: Realized + unrealized profit and loss (PnL) of
             :class:`.Portfolio`.
         fees: Brokerage fees.
     """
@@ -157,7 +156,6 @@ class PortfolioBar(NamedTuple):
     margin: Decimal
     market_value: Decimal
     pnl: Decimal
-    unrealized_pnl: Decimal
     fees: Decimal
 
 
@@ -260,6 +258,7 @@ class Portfolio:
         max_short_positions: Optional[int] = None,
     ):
         self.cash: Decimal = to_decimal(cash)
+        self._initial_market_value = self.cash
         self._fee_mode = fee_mode
         self._fee_amount: Optional[Decimal] = (
             None if fee_amount is None else to_decimal(fee_amount)
@@ -741,13 +740,12 @@ class Portfolio:
         """
         total_equity = self.cash
         total_market_value = total_equity
-        total_pnl = Decimal()
         total_margin = Decimal()
         for sym in self.symbols:
             index = (sym, date)
-            if index not in df.index:
-                continue
-            close = to_decimal(df.loc[index][DataCol.CLOSE.value])
+            close = None
+            if index in df.index:
+                close = to_decimal(df.loc[index][DataCol.CLOSE.value])
             pos_long_shares = Decimal()
             pos_short_shares = Decimal()
             pos_equity = Decimal()
@@ -756,46 +754,49 @@ class Portfolio:
             pos_pnl = Decimal()
             if sym in self.long_positions:
                 pos = self.long_positions[sym]
-                pos.equity = pos.shares * close
-                pos.market_value = pos.equity
-                pos.close = close
-                pos.pnl = _calculate_pnl(close, pos.entries, "long")
-                pos_long_shares += pos.shares
-                pos_equity += pos.equity
-                pos_market_value += pos.market_value
-                pos_pnl += pos.pnl
+                if close is not None:
+                    pos.equity = pos.shares * close
+                    pos.market_value = pos.equity
+                    pos.close = close
+                    pos.pnl = _calculate_pnl(close, pos.entries, "long")
+                    pos_long_shares += pos.shares
+                    pos_equity += pos.equity
+                    pos_market_value += pos.market_value
+                    pos_pnl += pos.pnl
                 total_equity += pos.equity
                 total_market_value += pos.equity
-                total_pnl += pos.pnl
             if sym in self.short_positions:
                 pos = self.short_positions[sym]
-                pos.close = close
-                pos.pnl = _calculate_pnl(close, pos.entries, "short")
-                pos.market_value = pos.pnl
-                pos.margin = close * pos.shares
-                pos_short_shares += pos.shares
-                pos_market_value += pos.pnl
-                pos_pnl += pos.pnl
-                pos_margin += pos.margin
+                if close is not None:
+                    pos.close = close
+                    pos.pnl = _calculate_pnl(close, pos.entries, "short")
+                    pos.market_value = pos.pnl
+                    pos.margin = close * pos.shares
+                    pos_short_shares += pos.shares
+                    pos_market_value += pos.pnl
+                    pos_pnl += pos.pnl
+                    pos_margin += pos.margin
                 total_market_value += pos.market_value
-                total_pnl += pos.pnl
                 total_margin += pos.margin
-            self.position_bars.append(
-                PositionBar(
-                    symbol=sym,
-                    date=date,
-                    long_shares=pos_long_shares,
-                    short_shares=pos_short_shares,
-                    close=close,
-                    equity=pos_equity,
-                    market_value=pos_market_value,
-                    margin=pos_margin,
-                    unrealized_pnl=pos_pnl,
+            if close is not None:
+                self.position_bars.append(
+                    PositionBar(
+                        symbol=sym,
+                        date=date,
+                        long_shares=pos_long_shares,
+                        short_shares=pos_short_shares,
+                        close=close,
+                        equity=pos_equity,
+                        market_value=pos_market_value,
+                        margin=pos_margin,
+                        unrealized_pnl=pos_pnl,
+                    )
                 )
-            )
+
         self.equity = total_equity
         self.market_value = total_market_value
         self.margin = total_margin
+
         self.bars.append(
             PortfolioBar(
                 date=date,
@@ -803,8 +804,7 @@ class Portfolio:
                 equity=self.equity,
                 market_value=self.market_value,
                 margin=self.margin,
-                pnl=self.pnl,
-                unrealized_pnl=total_pnl,
+                pnl=self.market_value - self._initial_market_value,
                 fees=self.fees,
             )
         )
