@@ -15,9 +15,12 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+import numpy as np
+import pandas as pd
+import pytest
+import re
 from datetime import datetime
 from decimal import Decimal
-
 from joblib import Parallel
 from pybroker.common import (
     BarData,
@@ -28,11 +31,8 @@ from pybroker.common import (
     to_decimal,
     to_seconds,
     verify_data_source_columns,
+    verify_date_range,
 )
-import numpy as np
-import pandas as pd
-import pytest
-import re
 
 
 def test_bar_data_get_custom_data():
@@ -207,6 +207,14 @@ def test_verify_data_source_columns():
     assert True
 
 
+def test_verify_date_range_when_invalid_then_error():
+    with pytest.raises(
+        ValueError,
+        match=r"start_date (.*) must be on or before end_date (.*)\.",
+    ):
+        verify_date_range("2020-05-01", "2020-04-01")
+
+
 def test_verify_data_source_columns_when_missing_then_error():
     df = pd.DataFrame(columns=["symbol", "date", "open", "high", "low"])
     with pytest.raises(
